(dependencymanagement)=

# Application, dependency and version management.

(application_control)=

## application_control

```{eval-rst}
.. automodule:: simtools.application_control
   :members:
```

(dependencies)=

## dependencies

```{eval-rst}
.. automodule:: dependencies
   :members:
```

(version)=

## version

```{eval-rst}
.. automodule:: version
   :members:
```
